from . import mixins
from .HowFairIsChecker import HowFairIsChecker


__author__ = "https://github.com/jspaaks"
__email__ = 'j.spaaks@esciencecenter.nl'

__all__ = [
    "HowFairIsChecker",
    "mixins"
]
